@@ -1,6 +1,6 @@
 use crate::iterators::*;
 use crate::utils::{partial_compare, slice_from_raw_parts, slice_from_raw_parts_mut};
-use crate::StaticVec;
+use crate::{StaticString, StaticVec};
 use core::borrow::{Borrow, BorrowMut};
 use core::cmp::{Eq, Ord, Ordering, PartialEq};
 use core::fmt::{self, Debug, Formatter};
@@ -352,6 +352,20 @@ impl<T: Copy, const N: usize> From<&mut [T; N]> for StaticVec<T, N> {
   }
 }
 
+impl<const N1: usize, const N2: usize> From<StaticString<N1>> for StaticVec<u8, N2> {
+  #[inline(always)]
+  default fn from(string: StaticString<N1>) -> Self {
+    Self::new_from_slice(string.as_bytes())
+  }
+}
+
+impl<const N: usize> From<StaticString<N>> for StaticVec<u8, N> {
+  #[inline(always)]
+  fn from(string: StaticString<N>) -> Self {
+    string.into_bytes()
+  }
+}
+
 #[cfg(feature = "std")]
 #[doc(cfg(feature = "std"))]
 impl<T, const N: usize> From<Vec<T>> for StaticVec<T, N> {
