@@ -178,6 +178,13 @@ fn bounds_to_string() {
     "Current value of element at `start`: 1\nCurrent value of element at `end`: 4",
     itv.bounds_to_string()
   );
+  let mut v2 = StaticVec::<Box<i32>, 0>::new();
+  let it2 = v2.iter();
+  assert_eq!("Empty iterator!", it2.bounds_to_string());
+  let itm2 = v2.iter_mut();
+  assert_eq!("Empty iterator!", itm2.bounds_to_string());
+  let itv2 = v2.into_iter();
+  assert_eq!("Empty iterator!", itv2.bounds_to_string());
 }
 
 #[test]
@@ -202,16 +209,16 @@ fn clone() {
 
 #[test]
 fn clone_from_shorter() {
-  let src: StaticVec<u32, { 20 }> = (1..10).collect();
-  let mut dst: StaticVec<u32, { 20 }> = (0..15).collect();
+  let src: StaticVec<u32, 20> = (1..10).collect();
+  let mut dst: StaticVec<u32, 20> = (0..15).collect();
   dst.clone_from(&src);
   assert_eq!(dst, src);
 }
 
 #[test]
 fn clone_from_longer() {
-  let src: StaticVec<u32, { 20 }> = (0..15).collect();
-  let mut dst: StaticVec<u32, { 20 }> = (1..10).collect();
+  let src: StaticVec<u32, 20> = (0..15).collect();
+  let mut dst: StaticVec<u32, 20> = (1..10).collect();
   dst.clone_from(&src);
   assert_eq!(dst, src);
 }
